@@ -1,5 +1,6 @@
 
 import os
+import sys
 
 from paste.deploy import loadwsgi
 
@@ -16,6 +17,9 @@ def config_factory(args):
         config_url = 'config:%s' % (os.path.basename(config_file), )
         relative_to = os.path.dirname(config_file)
         global_conf = {}
+        for arg in args['args'][1:]:
+            key, value = arg.split('=')
+            global_conf[key] = value
 
     ctx = loadwsgi.loadcontext(
         loadwsgi.SERVER,
@@ -66,16 +70,24 @@ def app_factory(config):
 
 
 def server_factory(global_conf, host, port, *args, **kw):
+    additional_restart_arguments = []
+    for arg in sys.argv:
+        if '=' in arg and not arg.startswith('--'):
+            additional_restart_arguments.append(arg)
+
+    global_conf['mochi_backend_ip'] = '127.0.0.1'
     config_url = 'config:' + os.path.split(global_conf['__file__'])[1]
     relative_to = global_conf['here']
 
     def run(app):
         args = spawning_controller.DEFAULTS.copy()
+        override_args = [
+                '--factory=spawning.paste_factory.config_factory',
+                global_conf['__file__']]
+        override_args.extend(additional_restart_arguments)
         args.update(
             {'config_url': config_url, 'relative_to': relative_to, 'global_conf': global_conf,
-            'override_args': [
-                '--factory=spawning.paste_factory.config_factory',
-                global_conf['__file__']]})
+            'override_args': override_args})
 
         spawning_controller.run_controller(
             'spawning.paste_factory.config_factory', args)
